# StereoMiddleburyEval
Python package for evaluation dataset and tools from the [Middlebury stereo evaulation 2014](https://vision.middlebury.edu/stereo/data/scenes2014/) dataset.

## Install
```
pip install StereoMiddleburyEval
```